Math tools for PyAstronomy
------------------------------

A collection of  mathematical or numerical tools
with potential application throughout PyAstronomy.

.. toctree::
   :maxdepth: 1
   
   numericalDerivativesDoc.rst
   integratDoc.rst
   zerocross.rst
 
.. toctree::
   :maxdepth: 2
   
   toolbox.rst